@@ -1,7 +1,7 @@
 package Passwd::Unix::Alt;
 # ABSTRACT: Manipulate /etc/{passwd,shadow,group,gshadow} entries
 
-package Passwd::Unix;
+
 use vars qw($VERSION @ISA @EXPORT @EXPORT_OK);
 
 use warnings;
@@ -319,7 +319,7 @@ sub _set {
 	my ($file, $user, $pos, $val, $count) = @_;
 
 	my @t = split(/::/,(caller(1))[3]);
-	croak(qq/\n"_set" cannot be called from outside of Passwd::Unix!/) if $t[-2] ne 'Unix';
+	croak(qq/\n"_set" cannot be called from outside of Passwd::Unix::Alt!/) if $t[-2] ne 'Alt';
 	unless($_CHECK->{$t[-1]}($val)){
 		carp(qq/Incorrect parameters for "$t[-1]! Leaving unchanged..."/) if $self->warnings();
 		$errstr = qq/Incorrect parameters for "$t[-1]! Leaving unchanged..."/;
@@ -868,22 +868,22 @@ Passwd::Unix::Alt - Manipulate /etc/{passwd,shadow,group,gshadow} entries
 
 =head1 VERSION
 
-version 0.5202
+version 0.5203
 
 =head1 SYNOPSIS
 
 	use Passwd::Unix::Alt;
 
-	my $pu = Passwd::Unix->new();
+	my $pu = Passwd::Unix::Alt->new();
 
 	# adding a new user
         $pu->user("example", $pu->encpass("my_secret"), $pu->maxuid + 1, 10,
 					  "My User", "/home/example", "/bin/bash");
-	die $Passwd::Unix::errstr if $Passwd::Unix::errstr;
+	die $Passwd::Unix::Alt::errstr if $Passwd::Unix::Alt::errstr;
 
 	# change a user's password
 	$pu->passwd("example", $pu->encpass("newsecret"));
-	die $Passwd::Unix::errstr if $Passwd::Unix::errstr;
+	die $Passwd::Unix::Alt::errstr if $Passwd::Unix::Alt::errstr;
 
 	# list users
 	foreach my $user ($pu->users) {
@@ -895,7 +895,7 @@ version 0.5202
 
 	# delete user
 	$pu->del("example");
-	die $Passwd::Unix::errstr if $Passwd::Unix::errstr;
+	die $Passwd::Unix::Alt::errstr if $Passwd::Unix::Alt::errstr;
 
 	# or
 
@@ -907,10 +907,10 @@ version 0.5202
 
 	user("example", encpass("my_secret"), $pu->maxuid + 1, 10,
 	     "My User", "/home/example", "/bin/bash" );
-	die $Passwd::Unix::errstr if $Passwd::Unix::errstr;
+	die $Passwd::Unix::Alt::errstr if $Passwd::Unix::Alt::errstr;
 
 	passwd("example",encpass("newsecret"));
-	die $Passwd::Unix::errstr if $Passwd::Unix::errstr;
+	die $Passwd::Unix::Alt::errstr if $Passwd::Unix::Alt::errstr;
 
 	foreach my $user (users()) {
 	    print "Username: $user\nFull Name: ", gecos($user), "\n\n";
@@ -919,7 +919,7 @@ version 0.5202
 	my $uid = uid('example');
 
 	del("example");
-	die $Passwd::Unix::errstr if $Passwd::Unix::errstr;
+	die $Passwd::Unix::Alt::errstr if $Passwd::Unix::Alt::errstr;
 
 =head1 DESCRIPTION
 
@@ -928,23 +928,21 @@ The Passwd::Unix module provides an abstract interface to /etc/passwd,
 Unix::PasswdFile module (that one does not handle /etc/shadow file,
 what is necessary in modern systems like Sun Solaris 10 or Linux).
 
+=for Pod::Coverage .*
+
 =head1 ABOUT PASSWD::UNIX::ALT
 
 Passwd::Unix::Alt is a fork of Strzelecki Lukasz's L<Passwd::Unix> v0.52, which
 I forked to scratch some of I<my> itches, and which I hope can be merged back to
 Passwd::Unix eventually. The rest of the documentation is Passwd::Unix's.
 
-B<Note that the package is still Passwd::Unix>. This is so that
-Passwd::Unix::Alt is a simple drop-in replacement for Passwd::Unix (only a
-simple replace of 'require' or 'use' line is needed).
-
 Notable differences:
 
 =over 4
 
 =item * does not require root privileges unless necessary (useful for testing)
 
-=item * report error string in $Passwd::Unix::errstr
+=item * report error string in $Passwd::Unix::Alt::errstr
 
 Instead of just returning true/false status or carping to stderr..
 
@@ -997,14 +995,14 @@ This method is an alias for C<del_user>. It's for transition only.
 This method will delete the list of users. It has no effect if the supplied
 users do not exist.
 
-Set $Passwd::Unix::errstr on error.
+Set $Passwd::Unix::Alt::errstr on error.
 
 =item B<del_group( GROUPNAME0, GROUPNAME1... )>
 
 This method will delete the list of groups. It has no effect if the supplied
 groups do not exist.
 
-Set $Passwd::Unix::errstr on error.
+Set $Passwd::Unix::Alt::errstr on error.
 
 =item B<encpass( PASSWORD )>
 
@@ -1065,7 +1063,7 @@ list consisting of (PASSWORD, UID, GID, GECOS, HOMEDIR, SHELL), or
 undef if no such user exists. If you supply all seven parameters,
 the named user will be created or modified if it already exists.
 
-Set $Passwd::Unix::errstr on error.
+Set $Passwd::Unix::Alt::errstr on error.
 
 =item B<group( GROUPNAME [,GID, ARRAYREF] )>
 
@@ -1076,7 +1074,7 @@ consisting names of users in this GROUP. It will return undef and ref to empty a
 exists. If you supply all three parameters, the named group will be
 created or modified if it already exists.
 
-Set $Passwd::Unix::errstr on error.
+Set $Passwd::Unix::Alt::errstr on error.
 
 =item B<users()>
 
